%define anolis_release 4

# Disable leak tests
%bcond_with perl_DBD_MariaDB_enables_leak_test
# Perform optional net_ssleay tests
%bcond_with perl_DBD_MariaDB_enables_net_ssleay_test

Name:           perl-DBD-MariaDB
Version:        1.22
Release:        %{anolis_release}%{?dist}
Summary:        MariaDB and MySQL driver for the Perl5 Database Interface (DBI)
License:        GPL+ or Artistic
URL:            https://metacpan.org/release/DBD-MariaDB/
Source0:        https://cpan.metacpan.org/authors/id/P/PA/PALI/DBD-MariaDB-%{version}.tar.gz
Source1:        test-setup.t
Source2:        test-clean.t
Source3:        test-env.sh

Patch0:         DBD-MariaDB-1.21-Run-test-setup-and-clean.patch

BuildRequires:  findutils gcc make openssl-devel
BuildRequires:  mariadb-connector-c mariadb-connector-c-devel
BuildRequires:  perl-devel perl-generators perl-interpreter
BuildRequires:  perl(:VERSION) >= 5.8.1 perl(Config) perl(Data::Dumper)
BuildRequires:  perl(DBI) >= 1.608 perl(DBI::DBD) perl(DynaLoader)
BuildRequires:  perl(Devel::CheckLib) >= 1.12 perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(File::Spec) perl(Getopt::Long) perl(utf8)
BuildRequires:  perl(strict) perl(warnings)
# Tests
BuildRequires:  hostname mariadb mariadb-server
BuildRequires:  perl(B) perl(bigint) perl(constant)
BuildRequires:  perl(DBI::Const::GetInfoType)
BuildRequires:  perl(File::Path) perl(File::Temp)
BuildRequires:  perl(FindBin) perl(lib) perl(CPAN::Meta::YAML)
BuildRequires:  perl(Test::Deep) perl(Test::More) >= 0.90
BuildRequires:  perl(Time::HiRes) perl(vars) perl(Encode)
# Optional tests
%if %{with perl_DBD_MariaDB_enables_net_ssleay_test}
BuildRequires:  perl(Net::SSLeay)
%endif
%if %{with perl_DBD_MariaDB_enables_leak_test}
BuildRequires:  perl(Proc::ProcessTable) perl(Storable)
%endif

# Filter private modules for tests
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}perl\\(lib.pl\\)

%description
DBD::MariaDB is the Perl DBI driver for access to MariaDB and MySQL databases.
The goal of DBD::MariaDB is to fix MariaDB compatibility, Perl Unicode support 
and security related bugs. This Perl DBI driver is a fork of the DBD::mysql driver
and was created because said issues in the  original DBD::mysql have not been 
addressed for more than a year.

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{EVR}
Requires:       perl-Test-Harness perl(CPAN::Meta::YAML)
Requires:       hostname mariadb mariadb-server

%if %{with perl_DBD_MariaDB_enables_net_ssleay_test}
Requires:       perl(Net::SSLeay)
%endif
%if %{with perl_DBD_MariaDB_enables_leak_test}
Requires:       perl(Proc::ProcessTable) perl(Storable)
%endif

%description tests
Tests from %{name}. Execute them with "%{_libexecdir}/%{name}/test".

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n DBD-MariaDB-%{version} -p1
cp %{SOURCE1} %{SOURCE2} t/

for F in t/*.t t/*.pl; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

# Remove release tests
for F in t/pod.t t/manifest.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
    perl -i -ne 'print $_ unless m{\Q'"$F"'\E}' t/testrules.yml
done

%if %{without perl_DBD_MariaDB_enables_leak_test}
# Remove unused tests
for F in t/60leaks.t t/rt86153-reconnect-fail-memory.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
    perl -i -ne 'print $_ unless m{\Q'"$F"'\E}' t/testrules.yml
done
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="$RPM_OPT_FLAGS" NO_PERLLOCAL=1 NO_PACKLIST=1
%{make_build}

%install
%{make_install}
find %{buildroot} -name '*.bs' -type f -size 0 -delete

# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
install -m 0644 -p t/* %{buildroot}%{_libexecdir}/%{name}
install -m 0644 -p %{SOURCE3} %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << EOF
#!/bin/sh
unset RELEASE_TESTING
. %{_libexecdir}/%{name}/$(basename %{SOURCE3})
cd %{_libexecdir}/%{name} && exec prove -I .
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test

%{_fixperms} %{buildroot}/*

%check
. %{SOURCE3}
unset RELEASE_TESTING
make test %{?with_perl_DBD_MariaDB_enables_leak_test:EXTENDED_TESTING=1}

%files
%license LICENSE
%{perl_vendorarch}/auto/*
%{perl_vendorarch}/DBD*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%files doc
%doc Changes.historic Changes

%changelog
* Mon Apr 10 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.22-4
- Optimize the spec file

* Wed Feb 08 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.22-3
- remove versioned MODULE_COMPAT_ requires

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.22-2
- rebuild with perl 5.36.0

* Mon Oct 10 2022 happy_orange <songnannan@linux.alibaba.com> - 1.22-1
- Init package from upstream
